@@ -36,3 +36,12 @@ test_that("position_stackv() supports `hjust` argument", {
 
   check_horizontal(v, h, "position-stackv() with `hjust` argument")
 })
+
+test_that("position_dodge2v() reverses the order within each bar group", {
+  # create doppelganger 
+  g <- mpg %>% 
+    ggplot(aes(x = cty, y = class, fill = drv)) +
+    geom_boxploth()
+  
+  vdiffr::expect_doppelganger("Boxplot with legend order aligned to bar order", g)
+})
\ No newline at end of file
