@@ -1,16 +1,17 @@
 context("Stats")
 
 test_that("stat_summaryh() flips", {
+
   fn_data_v <- function(x) {
-    set_names(
+    stats::setNames(
       boxplot.stats(x)$stats,
       c("ymin","lower", "middle","upper","ymax")
     )
   }
   fn_data_h <- function(x) {
-    set_names(
+    stats::setNames(
       boxplot.stats(x)$stats,
-      c("xmin","lower", "middle","upper","xmax")
+      c("xmin","xlower", "xmiddle","xupper","xmax")
     )
   }
   v <- ggplot(mtcars, aes(x = factor(cyl), y = mpg)) +
@@ -21,7 +22,7 @@ test_that("stat_summaryh() flips", {
 
   fn_xmin <- function(x) fn_data_h(x)[["xmin"]]
   fn_xmax <- function(x) fn_data_h(x)[["xmax"]]
-  fn_x <- function(x) fn_data_h(x)[["middle"]]
+  fn_x <- function(x) fn_data_h(x)[["xmiddle"]]
 
   v <- ggplot(mtcars, aes(x = factor(cyl), y = mpg)) +
     stat_summary(
@@ -38,4 +39,13 @@ test_that("stat_summaryh() flips", {
       geom = "pointrangeh"
     )
   check_horizontal(v, h, "stat_summaryh() with fun.x*()")
+
+})
+
+test_that("stat_summaryh() flips, with median_hilow_h summary", {
+  v <- ggplot(mtcars, aes(x = factor(cyl), y = mpg)) +
+    stat_summary(fun.data = median_hilow)
+  h <- ggplot(mtcars, aes(x = mpg, y = factor(cyl))) +
+    stat_summaryh(fun.data = median_hilow_h)
+  check_horizontal(v, h, "stat_summaryh() with median_hilow_h()")
 })
